@@ -8,11 +8,12 @@ from .kernels import (
     nuts,
     orbital_hmc,
     rmh,
+    sgld,
     tempered_smc,
     window_adaptation,
 )
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 
 __all__ = [
     "hmc",  # mcmc
@@ -21,6 +22,7 @@ __all__ = [
     "orbital_hmc",
     "rmh",
     "elliptical_slice",
+    "sgld",  # stochastic gradient mcmc
     "window_adaptation",  # mcmc adaptation
     "adaptive_tempered_smc",  # smc
     "tempered_smc",
