@@ -4,8 +4,8 @@ from typing import Callable, NamedTuple, Tuple
 import jax
 import jax.numpy as jnp
 
-import blackjax.optimizers as optimizers
-from blackjax.inference.hmc.base import HMCState
+import blackjax.adaptation.optimizers as optimizers
+from blackjax.mcmc.hmc import HMCState
 
 __all__ = [
     "dual_averaging_adaptation",
@@ -63,8 +63,8 @@ def dual_averaging_adaptation(
     the error at time t. We would like to find a procedure that adapts the
     value of :math:`\\epsilon` such that :math:`h(x) =\\mathbb{E}\\left[H_t|\\epsilon\\right] = 0`
 
-    Following [1]_, the authors of [2]_ proposed the following update scheme. If
-    we note :math:``x = \\log \\epsilon` we follow:
+    Following [Nesterov2009]_, the authors of [Hoffman2014]_ proposed the following update scheme. If
+    we note :math:`x = \\log \\epsilon` we follow:
 
     .. math:
         x_{t+1} \\LongLeftArrow \\mu - \\frac{\\sqrt{t}}{\\gamma} \\frac{1}{t+t_0} \\sum_{i=1}^t H_i
@@ -74,21 +74,21 @@ def dual_averaging_adaptation(
     :math:`h(\\overline{x}_t)` converges to 0, i.e. the Metropolis acceptance
     rate converges to the desired rate.
 
-    See reference [2]_ (section 3.2.1) for a detailed discussion.
+    See reference [Hoffman2014a]_ (section 3.2.1) for a detailed discussion.
 
     Parameters
     ----------
     t0: float >= 0
         Free parameter that stabilizes the initial iterations of the algorithm.
-        Large values may slow down convergence. Introduced in [2]_ with a default
+        Large values may slow down convergence. Introduced in [Hoffman2014a]_ with a default
         value of 10.
-    gamma
-        Controls the speed of convergence of the scheme. The authors of [2]_ recommend
+    gamma:
+        Controls the speed of convergence of the scheme. The authors of [Hoffman2014a]_ recommend
         a value of 0.05.
     kappa: float in ]0.5, 1]
         Controls the weights of past steps in the current update. The scheme will
         quickly forget earlier step for a small value of `kappa`. Introduced
-        in [2]_, with a recommended value of .75
+        in [Hoffman2014a]_, with a recommended value of .75
     target:
         Target acceptance rate.
 
@@ -102,11 +102,11 @@ def dual_averaging_adaptation(
     References
     ----------
 
-    .. [1]: Nesterov, Yurii. "Primal-dual subgradient methods for convex
+    .. [Nesterov2009] Nesterov, Yurii. "Primal-dual subgradient methods for convex
             problems." Mathematical programming 120.1 (2009): 221-259.
-    .. [2]: Hoffman, Matthew D., and Andrew Gelman. "The No-U-Turn sampler:
-            adaptively setting path lengths in Hamiltonian Monte Carlo." Journal
-            of Machine Learning Research 15.1 (2014): 1593-1623.
+    .. [Hoffman2014a] Hoffman, Matthew D., and Andrew Gelman. "The No-U-Turn sampler:
+           adaptively setting path lengths in Hamiltonian Monte Carlo." Journal
+           of Machine Learning Research 15.1 (2014): 1593-1623.
     """
     da_init, da_update, da_final = optimizers.dual_averaging(t0, gamma, kappa)
 
@@ -183,7 +183,7 @@ def find_reasonable_step_size(
     value for the step size starting from any value, choosing a good first
     value can speed up the convergence. This heuristics doubles and halves the
     step size until the acceptance probability of the HMC proposal crosses the
-    target value.
+    target value [Hoffman2014b]_.
 
     Parameters
     ----------
@@ -208,11 +208,12 @@ def find_reasonable_step_size(
     float
         A reasonable first value for the step size.
 
-    Reference
-    ---------
-    .. [1]: Hoffman, Matthew D., and Andrew Gelman. "The No-U-Turn sampler:
-            adaptively setting path lengths in Hamiltonian Monte Carlo." Journal
-            of Machine Learning Research 15.1 (2014): 1593-1623.
+    References
+    ----------
+    .. [Hoffman2014b] Hoffman, Matthew D., and Andrew Gelman. "The No-U-Turn sampler:
+           adaptively setting path lengths in Hamiltonian Monte Carlo." Journal
+           of Machine Learning Research 15.1 (2014): 1593-1623.
+
     """
     fp_limit = jnp.finfo(jax.lax.dtype(initial_step_size))
 
@@ -228,9 +229,9 @@ def find_reasonable_step_size(
         occur any performance penalty when calling it repeatedly inside this
         function.
 
-        Reference
-        ---------
-        .. [1]: jax.numpy.finfo documentation. https://jax.readthedocs.io/en/latest/_autosummary/jax.numpy.finfo.html
+        References
+        ----------
+        .. [1] jax.numpy.finfo documentation. https://jax.readthedocs.io/en/latest/_autosummary/jax.numpy.finfo.html
 
         """
         _, direction, previous_direction, step_size = rss_state
@@ -248,7 +249,7 @@ def find_reasonable_step_size(
         rng_key, direction, _, step_size = rss_state
         _, rng_key = jax.random.split(rng_key)
 
-        step_size = (2.0 ** direction) * step_size
+        step_size = (2.0**direction) * step_size
         kernel = kernel_generator(step_size)
         _, info = kernel(rng_key, reference_state)
 
