@@ -5,6 +5,7 @@ import jax.numpy as jnp
 
 import blackjax.adaptation as adaptation
 import blackjax.mcmc as mcmc
+import blackjax.sgmcmc as sgmcmc
 import blackjax.smc as smc
 from blackjax.base import AdaptationAlgorithm, SamplingAlgorithm
 from blackjax.progress_bar import progress_bar_scan
@@ -17,6 +18,7 @@ __all__ = [
     "nuts",
     "orbital_hmc",
     "rmh",
+    "sgld",
     "tempered_smc",
     "window_adaptation",
 ]
@@ -389,6 +391,92 @@ class nuts:
         return SamplingAlgorithm(init_fn, step_fn)
 
 
+# -----------------------------------------------------------------------------
+#                        STOCHASTIC GRADIENT MCMC
+# -----------------------------------------------------------------------------
+
+
+class sgld:
+    """Implements the (basic) user interface for the SGLD kernel.
+
+    The general sgld kernel (:meth:`blackjax.mcmc.sgld.kernel`, alias `blackjax.sgld.kernel`) can be
+    cumbersome to manipulate. Since most users only need to specify the kernel
+    parameters at initialization time, we provide a helper function that
+    specializes the general kernel.
+
+    Example
+    -------
+
+    To initialize a SGLD kernel one needs to specify a schedule function, which
+    returns a step size at each sampling step, and a gradient estimator
+    function. Here for a constant step size, and `data_size` data samples:
+
+    .. code::
+
+        schedule_fn = lambda _: 1e-3
+        grad_fn = blackjax.sgmcmc.gradients.grad_estimator(logprior_fn, loglikelihood_fn, data_size)
+
+    We can now initialize the sgld kernel and the state:
+
+    .. code::
+
+        sgld = blackjax.sgld(grad_fn, schedule_fn)
+        state = sgld.init(position)
+
+    Assuming we have an iterator `batches` that yields batches of data we can perform one step:
+
+    .. code::
+
+        data_batch = next(batches)
+        new_state = sgld.step(rng_key, state, data_batch)
+
+    Kernels are not jit-compiled by default so you will need to do it manually:
+
+    .. code::
+
+       step = jax.jit(sgld.step)
+       new_state, info = step(rng_key, state)
+
+    Parameters
+    ----------
+    gradient_estimator_fn
+       A function which, given a position and a batch of data, returns an estimation
+       of the value of the gradient of the log-posterior distribution at this position.
+    schedule_fn
+       A function which returns a step size given a step number.
+
+    Returns
+    -------
+    A ``SamplingAlgorithm``.
+
+    """
+
+    init = staticmethod(sgmcmc.sgld.init)
+    kernel = staticmethod(sgmcmc.sgld.kernel)
+
+    def __new__(  # type: ignore[misc]
+        cls,
+        grad_estimator_fn: Callable,
+        schedule_fn: Callable,
+    ) -> SamplingAlgorithm:
+
+        step = cls.kernel(grad_estimator_fn)
+
+        def init_fn(position: PyTree, data_batch: PyTree):
+            return cls.init(position, data_batch, grad_estimator_fn)
+
+        def step_fn(rng_key: PRNGKey, state, data_batch: PyTree):
+            step_size = schedule_fn(state.step)
+            return step(rng_key, state, data_batch, step_size)
+
+        return SamplingAlgorithm(init_fn, step_fn)  # type: ignore[arg-type]
+
+
+# -----------------------------------------------------------------------------
+#                                 ADAPTATION
+# -----------------------------------------------------------------------------
+
+
 def window_adaptation(
     algorithm: Union[hmc, nuts],
     logprob_fn: Callable,
